@@ -257,8 +257,7 @@ module Google
             @values[key] = @defaults[key]
             @values[key].reset! if @validators[key] == SUBCONFIG
           elsif @values.key? key
-            warn! "Key #{key.inspect} has not been added, but has a value." \
-                  " Removing the value."
+            warn! "Key #{key.inspect} has not been added, but has a value. Removing the value."
             @values.delete key
           else
             warn! "Key #{key.inspect} does not exist. Nothing to reset."
@@ -308,9 +307,7 @@ module Google
       #
       def [] key
         key = resolve_key! key
-        unless @validators.key? key
-          warn! "Key #{key.inspect} does not exist. Returning nil."
-        end
+        warn! "Key #{key.inspect} does not exist. Returning nil." unless @validators.key? key
         value = @values[key]
         value = value.call if Config::DeferredValue === value
         value
@@ -338,6 +335,7 @@ module Google
       def field? key
         @validators[key.to_sym].is_a? ::Proc
       end
+      alias respond_to? field?
 
       ##
       # Check if the given key has been explicitly added as a subconfig name.
@@ -358,7 +356,7 @@ module Google
       #
       def alias? key
         target = @validators[key.to_sym]
-        target.is_a?(::Symbol) ? target : nil
+        target.is_a?(::Symbol) ? target : nil # rubocop:disable Style/ReturnNilInPredicateMethodDefinition
       end
 
       ##
@@ -397,11 +395,12 @@ module Google
       def to_s!
         elems = @validators.keys.map do |k|
           v = @values[k]
-          vstr = Config.config?(v) ? v.to_s! : value.inspect
+          vstr = Config.config?(v) ? v.to_s! : v.inspect
           " #{k}=#{vstr}"
         end
         "<Config:#{elems.join}>"
       end
+      alias inspect to_s!
 
       ##
       # Returns a nested hash representation of this configuration state,
@@ -458,8 +457,8 @@ module Google
       def method_missing name, *args
         name_str = name.to_s
         super unless name_str =~ /^[a-zA-Z]\w*=?$/
-        if name_str.chomp! "="
-          self[name_str] = args.first
+        if name_str.end_with? "="
+          self[name_str[0...-1]] = args.first
         else
           self[name]
         end
@@ -484,27 +483,37 @@ module Google
         false
       end
 
+      ##
+      # @private
+      # Implement standard is_a check
+      #
+      # @return [boolean]
+      #
+      def is_a? klass
+        klass == Config
+      end
+
       private
 
       ##
       # @private A validator that allows all values
       #
-      OPEN_VALIDATOR = ::Proc.new { true }
+      OPEN_VALIDATOR = proc { true }
 
       ##
       # @private a list of key names that are technically illegal because
       # they clash with method names.
       #
-      ILLEGAL_KEYS = %i[
-        add_options
-        initialize
-        instance_eval
-        instance_exec
-        method_missing
-        singleton_method_added
-        singleton_method_removed
-        singleton_method_undefined
-      ].freeze
+      ILLEGAL_KEYS = [:add_options,
+                      :initialize,
+                      :inspect,
+                      :instance_eval,
+                      :instance_exec,
+                      :method_missing,
+                      :send,
+                      :singleton_method_added,
+                      :singleton_method_removed,
+                      :singleton_method_undefined].freeze
 
       ##
       # @private sentinel indicating a subconfig in the validators hash
@@ -521,12 +530,9 @@ module Google
         key_str = key.to_s
         key = key.to_sym
         if key_str !~ /^[a-zA-Z]\w*$/ || ILLEGAL_KEYS.include?(key)
-          warn! "Illegal key name: #{key_str.inspect}. Method dispatch will" \
-                " not work for this key."
-        end
-        if @validators.key? key
-          warn! "Key #{key.inspect} already exists. It will be replaced."
+          warn! "Illegal key name: #{key_str.inspect}. Method dispatch will not work for this key."
         end
+        warn! "Key #{key.inspect} already exists. It will be replaced." if @validators.key? key
         key
       end
 
@@ -569,13 +575,11 @@ module Google
         case validator
         when ::Proc
           unless validator.call value
-            warn! "Invalid value #{value.inspect} for key #{key.inspect}." \
-                  " Setting anyway."
+            warn! "Invalid value #{value.inspect} for key #{key.inspect}. Setting anyway."
           end
         when Config
           if value != validator
-            warn! "Key #{key.inspect} refers to a subconfig and shouldn't" \
-                  " be changed. Setting anyway."
+            warn! "Key #{key.inspect} refers to a subconfig and shouldn't be changed. Setting anyway."
           end
         else
           warn! "Key #{key.inspect} has not been added. Setting anyway."
